# Claude Code Instructions

## Tinker-style Training SDK

When working on the tinker-style training SDK, **only look at code in `src/fireworks/training/`**. Do not reference or modify training-related code outside of this directory.

This SDK repo contains auto-generated code from Stainless outside of `src/fireworks/training/`. The training SDK is developed independently and lives entirely within that directory.
